draw_aois: Draw one or more areas of interest, AOIs, on one or more...

View source: R/AnalysisFunctions.R

draw_aoisR Documentation

Draw one or more areas of interest, AOIs, on one or more stimulus images and save the coordinates to the R prompt. The function returns a data frame with all saved AOIs. By default, AOIs are drawn in a coordinate system where y is 0 in the lower extreme of the image, e.g., an ascending y axis. Tobii eye trackers use a coordinate system with a descending y-axis, e.g., x and y are 0 in the upper left corner of the image. Make sure that your AOIS match the coordinate system of your eye tracker output. By setting the parameter reverse.y.axis to TRUE, the saved AOIs will be reformatted to fit a coordinate system with a descending y-axis. All AOIS have the variables xmin, xmax, ymin and ymax. xmin is the minimum x value, ymin the minimum y value. xmax the maximum x value. ymax the maximum y value. Major updates to this function were made in version 1.1.4

Description

Draw one or more areas of interest, AOIs, on one or more stimulus images and save the coordinates to the R prompt. The function returns a data frame with all saved AOIs. By default, AOIs are drawn in a coordinate system where y is 0 in the lower extreme of the image, e.g., an ascending y axis. Tobii eye trackers use a coordinate system with a descending y-axis, e.g., x and y are 0 in the upper left corner of the image. Make sure that your AOIS match the coordinate system of your eye tracker output. By setting the parameter reverse.y.axis to TRUE, the saved AOIs will be reformatted to fit a coordinate system with a descending y-axis. All AOIS have the variables xmin, xmax, ymin and ymax. xmin is the minimum x value, ymin the minimum y value. xmax the maximum x value. ymax the maximum y value. Major updates to this function were made in version 1.1.4

Usage

draw_aois(img_paths)

Arguments

img_paths

can be either the path to a directory where one or more images van be found OR an array of paths to one or more images.

Value

data frame with type and coordinates of drawn AOIs


kollaR documentation built on May 8, 2026, 5:07 p.m.